@@ -1,5 +1,5 @@
 from beartype import beartype
-from typing import Union
+from beartype.typing import Union
 
 degrees_per_meters = 0.00006
 
